%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: SetupDataStatic.m
%
% Description: Script that contains all initialization required
%              to generate simulated data.
%
% Inputs: As written into m-file. 
%
% Outputs: Parameters required for signal generation.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2005-08-23.
%
% Firm revision: revision 2.0, 2005-08-23. 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
% Set up parameters for data generation
%

% dimensions...

nu=2; % Input signal dimension
nx_0=0; % State dimension
ny=1; % Output dimension, normally 1

% Input signal related...Type may be selected among:
%
% InputType=[
%    'PRBS       ';
%    'Gaussian   ';
%    'UniformPRBS';
%    'SineWave   ';
%    'Custom     '];
   
InputType=[
   'UniformPRBS';
   'UniformPRBS'];
uAmplitude=[
   1.0;
	1.0];
uMean=[
   0;
	0];
uFrequency=[
   0;
	0];
ClockPeriod=[
   10;
	15];% Clock period vector in terms of sampling time

% System disturbance related...Type may be selected among:
%
% DisturbanceTypeSystem=[
%   'WGN     ';
%   'SineWave';
%   'Custom  '];

DisturbanceTypeSystem=[];
wSigma=[]; % Gaussian system noise standard deviation (discrete time)
wMean=[];
wSineAmplitude=[];
wSineFrequency=[];

% Measurement disturbance related... Type may be selected among:
%
% DisturbanceTypeMeasuremet=[
%   'WGN     ';
%   'SineWave';
%   'Custom  '];

DisturbanceTypeMeasurement=[
   'WGN     '];
eSigma=0.01; % Gaussian measurement noise standard deviation (discrete time)
eMean=[
   0];
eSineAmplitude=[
   0];
eSineFrequency=[
   0];

% sampling time and data length

Ts=0.1; % Sampling time in seconds
N=10000; % Number of data points
SamplingInstances=(Ts:Ts:N*Ts);

% ODE related...

x0=zeros(0,1); % Initial values
