%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: dfdtheta_m.m
%
% Description: This m-file generates the parameter sensitivity 
%              of the RHS of the ODE model. 
%
% Inputs: x_m - current model state
%         u - current input
%         theta - current parameter vector
%         allIndices - Matrix with all powers
%
% Outputs: dfdtheta_m - parameter sensitivities
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2003-05-20.
%
% Firm revision: revision 1.0, 2004-12-23.
%					  revision 2.0, 2005-08-24 (no changes).
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [dfdtheta_m]=dfdtheta_m(x_m,u,theta,allIndices)

extendedState=[
   x_m;
   u];
numberOfIndicesInSum=size(allIndices,1);

nx=size(x_m,1);
ntheta=size(theta,1);
dfdtheta_m=zeros(nx,ntheta);

for i=1:ntheta
 
  % One sensitivity component corresponds to one index state
   
   thisIndex=allIndices(i,:);
   prod1=1;   
   for j=1:size(thisIndex,2)
      for k=1:thisIndex(1,j)
         prod1=prod1*extendedState(j,1);
      end
   end
   dfdtheta_m(nx,i)=prod1;
end

