%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: f_m.m
%
% Description: The RHS of the ODE model that is accessed by  
%              the Euler numerical integration routine. Used 
%              for model state prediction. 
%
% Inputs: x_m - current model state
%         u - current input
%         theta - current parameter vector
%         allIndices - Matrix with all powers
%
% Outputs: f_m - RHS of ODE
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2003-05-02.
%
% Firm revision: revision 1.0, 2004-12-23.
%					  revision 2.0, 2005-08-24 (no changes).
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [f_m]=f(x_m,u,theta,allIndices)

nx=size(x_m,1);
for i=1:nx-1
   f_m(i,1)=x_m(i+1,1);
end;

extendedState=[
   x_m;
   u];
numberOfIndicesInSum=size(allIndices,1);

RHS=0;
for i=1:numberOfIndicesInSum % Loop over all relevant combinations
   
   % add one term to the sum, correspondig to one index state
   
   thisIndex=allIndices(i,:);
   prod1=1;
   for j=1:size(thisIndex,2)
      for k=1:thisIndex(1,j)
         prod1=prod1*extendedState(j,1);
      end
   end
   RHS=RHS+theta(i,1)*prod1;
end
f_m(nx,1)=RHS;
