%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: hStatic_m.m
%
% Description: The static nonlinear output model.
%
% Inputs: n_y - the output order 
% 			 x_m - current model state - not relevant here
%         u - current input
%         theta - current parameter vector
%         allIndices - Matrix with all powers
%
% Outputs: f_m - Output function value
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2005-08-23.
%
% Firm revision: revision 2.0, 2005-08-23.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [hStatic_m]=hStatic(ny,x_m,u,theta,allIndices)

extendedState=[
   x_m;
   u];
numberOfIndicesInSum=size(allIndices,1);

RHS=0;
for i=1:numberOfIndicesInSum % Loop over all relevant combinations
   
   % add one term to the sum, correspondig to one index state
   
   thisIndex=allIndices(i,:);
   prod1=1;
   for j=1:size(thisIndex,2)
      for k=1:thisIndex(1,j)
         prod1=prod1*extendedState(j,1);
      end
   end
   RHS=RHS+theta(i,1)*prod1;
end
hStatic_m(ny,1)=RHS;
